	* 1BA3 Lab #2, 31st October 2000
	* Written by Edsko de Vries

	* 5. 
	* [Input the following program, save it to a file, assemble it and run it.]
	* It will add the word value at memory location $2000 to the word value
	* at $2002 and store the result at $2004. Verify that it is working.

***
* Some simulator specific definitions
****
CPUHALT	EQU	$F000

***
* The main program 
****
	org	$1000

	move	$2000,d0	* Load d0 from memory
	move	$2002,d1	* Load d1 from memory
	add	d0,d1		* d1 := d0 + d1
	move	d1,$2004	* Store d1 to memory

	dc.w 	CPUHALT		* Halt the CPU

***
* Some sample data
****
	org	$2000
	dc.w	$111
	dc.w	$222
