	* 1BA3 Lab #3, 31st October 2000
	* Written by Edsko de Vries

	* 3.
	* Run the program 
	*
	*    add.b d0,d1
	*
	* with values in the data registers that will generate
	* the following condition codes:
	*
	* C=0 and V=0
	* C=1 and V=0
	* C=0 and V=1
	* C=1 and V=1

***
* Some simulator specific definitions
****
CPUHALT	EQU	$F000

***
* The main program
****
	org	$1000
	
	* C=0, V=0
	move.b	#10,d0
	move.b	#20,d1
	add.b	d0,d1

	* C=1, V=0
	move.b	#240,d0
	move.b	#20,d1
	add.b	d0,d1

	* C=0, V=1
	move.b	#126,d0
	move.b	#5,d1
	add.b	d0,d1

	* C=1, V=1
	move.b	#-126,d0
	move.b	#-5,d1
	add.b	d0,d1

	dc.w	CPUHALT	
